bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 17. Aventiure
___________________________________________________
| ### DO ERBITEN si der nahte vnd fvren vber Rin ### von helden chvnde nimmer wirs geiaget sin ### ein tier daz si slvgen daz weinten edliv chint ### ia mvsen sin engelten vil gvte wigande sint ### Von grozer vebermvete mveget ir horen sagen ### vnd von eislicher rache do hiez Hagen tragen ### Sifrit also toten von Nibelvnge lant ### fver eine chæmenaten da man Criemhilde vant
###### 1001 | ### Er hiez in tovgenlichen legen an di tver ### daz sin da solde vinden so si gienge da fver ### zer mettine ê daz ez wrde tach ### der div vrowe Criemhilt vil selten deheine verlach
| ### Man lvte da cem mvenster nach gewoneheit ### vrov Criemhilt div schoene wachte manige meit ### ein lieht bat si ir bringen vnd ovch ir gewant ### do chom ein kamerære da er Sifriden vant
###### 1003 | ### Er sah in blvtes rôten sin wat was elliv naz ### daz ez sin herre wære nine wesse er daz ### hin cer kemenaten daz lieht trvg er an der hant ### von dem vil leiden mære div vrov Criemhilt ervant
###### 1004 | ### Do si mit ir vrowen cem mvnster wolde gan ### do sprach der chamerære ir svlt stille stan ### ez lit vor disem gadme ein ritter tot erslagen ### do begonde Criemhilt vil harte vmmæzliche chlagen
###### 1005 | ### <ê> daz si reht erfvnde daz iz wære ir man ### an di Hagenen vrage denchen si began ### wi er in solde vristen do wart ir erste leit ### von ir was allen vrevden von sinem tode widerseit
###### 1006 | ### Do seich si zv der erden daz si niht ensprach ### di schoenen vrevdelôsen ligen man do sach ### Criemhilde iamer wart vmmazen groz ### do erschre si nach vncreffte daz al div chemenate erdoz
###### 1007 | ### Do sprach daz gesinde waz ob ez ist ein gast ### daz blvt ir vz dem mvnde von hercen iamer brast ### do sprach si ez ist Sifrit der min vil [337b] lieber man ### ez hat geraten Prvennhilt daz ez hat Hagen getan
| ### Do vrowe hiez sich wisen da si den helt vant ### si hop sin hovbt schoene mit ir vil wizzen hant ### swi rot ez wære von blvte si het in schiere erchant ### do lach vil iæmerliche der helt von Nibelvnge lant
###### 1009 | ### Do rief vil trvrechliche div vrowe milt ### owe mich mines leides nv ist dir <din> shilt ### mit swerten niht verhowen div list ermorderot ### wesse ich wer iz het getan ich riet im immer sinen tot
###### 1010 | ### Allez ir gesinde chlagete vnd schre ### mit ir lieben vrowen wande in was harte we ### vmb ir vil edeln herren den si da heten velorn ### da het gerochen Hagene harte Prvnnhilde zorn
###### 1011 | ### <Do> sprach div iamerhaffte ir kamerære ir svlt hin gan ### vnd wechet harte balde di Sifrides man ### ir svlt ovch Sigemvnde minen iamer sagen ### ob er mir helffen welle den chvenen Sifride chlagen
###### 1012 | ### Do lief ein bote balde da er si ligen vant ### di Sifrides helde von Nibelvnge lant ### mit den vil leiden maren ir vrevd er in benam ### sine wolt es niht gelovben vnz man daz weinen vernam
###### 1013 | ### Der bote chom ovch schiere da der chvnich lach ### Sigemvnt der herre der slaffes niht enpflach ### ich wæne sin herce im sagte daz im was geschehen ### ern mohte sinen lieben svn nimmer lebendich gesehen
| ### Vachet herre Sigemvnt mich bat nach iv gan ### Criemhilt min vrowe der ist ein leit getan ### daz ir vor allen leiden an ir herce gat ### daz svlt ir chlagen helffen wand ez ivch sere bestat
###### 1015 | ### Vf rihte sich do Sigemvnt er sprach waz sint div leit ### der schonen Criemhilde div dv mir hast geseit ### der bote sprach mit weinen ine chan iv niht verdagen ### ia ist von Niderlande der chvene Sifrit erslagen
###### 1016 | ### Do sprach der herre Sigemvnt lat iwer schimpfen sin ### vnd also bosiv mære dvrch willen min ### daz ir ez saget iemen daz er si erslagen ### wand ine chvnd in nimmer vor minem tode verchlagen
###### 1017 | ### <Welt> ir mir niht gelovben daz ir mir horet sagen ### so mvget ir selbe hoeren Criemhilde klagen ### vnt allez ir gesinde den Sifrides tot ### vil <ser> scrachte do Sige [338a] mvnt des gie im werliche not
###### 1018 | ### Mit hvndert sinen mannen er von dem bette spranch ### si zvchten zv den henden div scharffen <waffen> lanch ### si lieffen zv dem wffe vil iamerliche dan ### do chomen tvsent rechen des chvenen Sifrides man
###### 1019 | ### Do si so iæmerliche di vrowen horten chlagen ### do wanden svemeliche si solden chleider tragen ### iane mohten si der sinne vor leide niht gehaben ### in wart vil michel swære in ir hercen begraben
| ### Do chom der chvene Sigemvnt da er Criemhilde vant ### er sprach owe der reise her in dize lant ### wer hat mich mines chindes vnd ivch des iweren man ### bi also gvten frivnden svs mortliche ane getan
###### 1021 | ### Hey sold ich den bechennen sprach daz vil edel wip ### holt wrde im nimmer min herce vnt ovch min lip ### ich geriete im also leide daz di frivnde sin ### von den minen schvlden mvsen weinende sin
###### 1022 | ### Sigemvnt der herre den fvrsten vmbesloz ### do wart von sinen vrivnden der iamer also groz ### daz von dem starchen wffe palas vnde sal ### vnd ovch di stat ce Wormze von ir weinen erschal
| ### Done niemen getroesten daz Sifrides wip ### man zoch vz den chleidern den sinen lip ### man wsch im sine wnden vnd leit in vf den re ### so was den sinen livten von grozem iamer starche we
###### 1024 | ### Do sprachen sine rechen von Nibelvnge lant ### in sol immer rechen mit willen vnser hant ### er ist in dirre bverge der iz hat getan ### do ilten nach den waffen alle Sifrides man
###### 1025 | ### Di vz erwelten degene mit schilden chomen dar ### einlef hvndert rechen di het an siner schar ### Sigemvnt der herre sines svnes tot ### den wold er gerne rechen des gie im wærlichen not
| ### Sine wessen wen si solden mit strite do bestan ### sine tæren ez danne Gvnther vnd sine man ### mit den der herre Sifrit an daz geieide reit ### Criemhilt sach si gewaffent daz was ir groezliche leit
###### 1027 | ### Swi michel wær ir iamer vnd swi starch ir not ### do vorhte der Nibelvnge tot ### von ir brvder mannen daz si ez vnderstvnt ### si warnt si als gvetliche so vrivnde liebe vrivnde tvnt
###### 1028 | ### Do sprach div iamers riche min herre Sigemvnt ### wes welt ir beginnen iv ist niht rehte chvnt ### ia hat der kvenich [338b] Gvnther so manigen chvenen man ### ir welt ivch alle vliesen svlt ir di rechen bestan
| ### Mit vf erbvnden schilden in was ce strite not ### div edel kvneginne bat vnd gebot ### daz siz miden solden di rechen vil gemeit ### do siz niht lazen wolden ei was ir wærlichen leit
###### 1030 | ### Si sprach herre Sigemvnt ir svlt iz lazen vnderstan ### vnz ez sich baz gefvege so wil ich minen man ### immer mit iv rechen der mir in hat benomen ### wird ich des bewiset ich sol im schædeliche chomen
###### 1031 | ### Ez ist der vebermveten hie bi Rine vil ### da von ich iv des strites raten niht en wil ### si habent wider einen ie wol drizech man ### nv laz in got gelingen als vmb vns gedienet han
| ### Ir svlt hie beliben vnt dolt mit mir miniv leit ### als iz tagen beginne ir helde vil gemeit ### so helffet mir besarchen den minen lieben man ### do sprachen di degene daz sol werden getan
###### 1033 | ### Iv enchvnde niemen daz wnder vol sagen ### von rittern vnt <von> vrowen wi man di horte chlagen ### so daz man des wffes wart in der stat gewar ### di edelen bvrgære di chomen gahende dar
###### 1034 | ### Si chlageten mit den gesten want in was harte leit ### daz Sifrides schvlde in niemen het geseit ### dvrch waz der edel reche verlvr den sinen lip ### do weinten mit den vrowen der gvten bvrgære wip
| ### Smide hiez man gahen wrchen einen sarch ### von silber vnd von golde vil michel vnd vil starch ### man hiez in vaste spengen mit stahel daz was gvt ### do was allen livten harte trvrech der mvt
###### 1036 | ### Div naht was cergangen man sagte ez wolde tagen ### do hiez div edel vrowe zv dem mvnster tragen ### Sifriden den herren den vil lieben man ### swaz er da vrivnde hete di sach man weinende gan
###### 1037 | ### Do si in cem mvnster brahten vil der gloken chlanch ### do hort man allenthalben vil maniges pfaffen sanch ### do chom der kvnich Gvnther mit den sinen man ### vnd ovch der grimme Hagene zv dem wffe gegan
| ### Er sprach vil liebiv swester owe der leide din ### daz wir niht ane des grozen schaden sin ### wir mvezen chlagen immer den Sifrides lip ### daz tvt ir ane schvlde sprach daz iamerhafte wip
###### 1039 | ### Wær iv dar vmbe leide son wær es niht <gesche [339a] hen> ### ir hetet min vergezzen des mag ich nv wol iehen ### da ich da wart gescheiden vnt min lieber man ### daz wolde got sprach Criemhilt vnd wær iz mir selber getan
###### 1040 | ### Si buten vaste ir lovgen Criemhilt begonde iehen ### swelher sich vnschvldige der laze daz gesehen ### der sol zv der bare vor den livten gen ### da bi mach man di warheit harte schiere versten
###### 1041 | ### Daz ist ein michel wnder vil dicke ez noch geschiht ### swa man den mortmeilen bi dem toten siht ### so blvtent im di wnden als ovch da geschach ### da von man di schvlde da ce Hagene gesach
| ### Di wnden vlvzzen sere alsam si taten ê ### di ê da sere chlageten des wart nv michel me ### do sprach der kvenich Gvnther ich wilz ivch wizzen lan ### in slvgen schachære Hagen hat es niht getan
###### 1043 | ### Mir sint di schachære sprach si vil wol bechant ### nv lazzez got errechen noch siner vrivnde hant ### Gvnther vnd Hagene ia habt ir iz getan ### di Sifrides degene heten gegen strite wan
###### 1044 | ### Do sprach aber Crimhilt habt mit mir di not ### do chomen dise beide da si in fvnden tot ### Gere ir brvder vnd Giselher daz chint ### in triwen si in chlageten mit den anderen sint
| ### Si weinten innechlichen den Crimhilde man ### man solde messe singen zv dem mvnster dan ### giengen allenthalben wip man vnt chint ### di sin doch liht enbaren di weinten Sifriden sint
###### 1046 | ### <Gernot> vnd Giselher di sprachen swester min ### nv troste dich nach tode als iz doch mvz sin ### wir wellen dichs ergeczen di wile wir geleben ### done chvnde ir trost deheinen cer werlde niemen gegeben [339b]
###### 1047 | ### Sin sarch der was bereitet wol vmbe einen mittentach ### man hvp in von der bare da er vffe lach ### ine wolde noch div <frowe> lazen niht begraben ### des mvsen al di livte michel arbeite haben
| ### In einen richen pfellel man den toten want ### ich wene man da iemen ane weinen vant ### do chlagete hercenliche Vte ein edel wip ### vnd allez ir gesinde den sinen wætlichen lip
###### 1049 | ### Do man daz gehorte daz man cem mvenster sanch ### vnt man in gesarchet hete do hvp sich groz gedranch ### dvrch willen siner sele waz opffers man do trvch ### er hete bi den vinden doch gvter vrivnde genvch
###### 1050 | ### Criemhilt div arme cen kameræren sprach ### si svln dvrch mine liebe liden vngemach ### di im iht gvtes gvennen vnd mir wesen holt ### dvrch Sifrides sele sol man teilen sin golt
| ### Dehein chint was da so chleine daz iht witze mohte haben ### daz mvse gen cem opffer ê wrde begraben ### baz danne hvndert messe man da des tages sanch ### von Sifrides vrivnden wart da grozer gedranch
###### 1052 | ### Do man da hete gesvngen daz volch hvp sich von dan ### do sprach div vrowe Criemhilt irn svlt eine lan ### hinte mich bewachen den vz erwelten degen ### ez ist an sinem libe al min vrevde gelegen
###### 1053 | ### Dri tage vnd dri nahte wil ich lazen stan ### vnz ich mich geniete mines vil lieben man ### waz ob daz got gebivtet daz mich nimt ovch der tot ### so wære wol verendet min armer Criemhilde not
| ### Cen herbergen giengen di livte von der stat ### pfaffen vnd mvenche si beliben bat ### vnd allez sin gesinde daz es des heldes pflach ### si heten naht vil arge vnt vil mlvelichen tach
###### 1055 | ### Ane ezzen vnd ane trinchen beleip da manich man ### di ez da nemen wolden den [340a] wart daz chvnt getan ### daz mans in den vollen gæbe daz schvf her Sigemvnt ### do was den Nibelvngen vil arbeite chvnt
###### 1056 | ### Di drie tagecite so wir horen sagen ### di da chvnden singen daz si mvsen tragen ### vil der arbeite waz man in opfers trvch ### di vil arme waren di wrden riche genvch
| ### Swaz man vant der armen di es niht mohten han ### di hei man cem opfer mit dem golde gan ### vz sin selbes kamern do er niht solde leben ### vmb sine sele wart manich tvsent march gegeben
###### 1058 | ### Vrbor vf der erden teilten si in div lant ### swa so man div kloster vnd gvte livte vant ### silbers vnd wæte gap man den armen genvch ### si tet dem wol <geliche> daz sim holden willen trvch
###### 1059 | ### An dem dritten morgen ce der rehten messecit ### so was bi dem mvnster der chirchof also wit ### von den lantlivten weinens also vol ### si dienten im nach tode also man lieben vrivnden sol
| ### In den tagen vieren man hat gesaget daz ### ce drizech tvsent marchen oder dannoch baz ### wart dvrch sine <sele> den armen da gegebn ### do was gelegen ringe sin groziv schone vnd ovch sin leben
###### 1061 | ### Do got da wart gedienet daz man vol sanch ### mit vngefvegem leide vil des volches ranch ### man hiez in vz dem mvenster zv dem grabe tragen ### di sin vngern enbaren di sah man weinen vnd chlagen
###### 1062 | ### Vil lvte schriende daz livt gi mit im dan ### vro en was da niemen weder wip noch man ### ê daz man in begrvobe man sanch vnd las ### <hey> waz gvter pfaffen ce siner pifilde was
| ### E daz cem grabe choeme daz Sifrides wip ### do ranch so mit iamer ir getriwer lip ### daz man si mit dem brvnnen vil dicke da vergoz ### ez was ir vngemvete vil harte vnmæzlichen groz
###### 1064 | ### Ez was ein michel wnder daz si ie genas [340b] ### mit chlage ir helfende manich vrowe was ### do sprach div chveneginne ir Sifrides man ### ir svlt dvrch iwer triwe an mir genade began
###### 1065 | ### Lat mir nach minem leide daz chleine liep geschehen ### daz ich sin schoene hovbt noch eines mveze sehen ### do bat sis also lange mit iamers sinnen starch ### daz man cebrechen mvse do den herlichen <sarch>
| ### Do brahte man di vrowen da si in ligen vant ### si hvp sin schoene hovbt mit ir vil wizzen hant ### do chvstes also toten den edel ritter gvt ### div ir vil liehten ovgen vor leide weinten blvt
###### 1067 | ### Ein iamergez scheiden wart do da getan ### do trvch man si von dannen sine chvnde niht gegan ### do vant man sinnelose daz herliche wip ### vor leide moht ersterben der ir vil wnnechlicher lip
###### 1068 | ### Do man den edelen herren hete nv begraben ### leit ane maze sah man di alle haben ### di mit im chomen waren von Nibelvnge lant ### vil selten vroelichen man do Sigemvnden vant
| ### Da was der etlicher der drier tage lanch ### vor dem grozem leide niht az noch entranch ### do mohten si dem libe so gar geswichen niht ### si nerten sich nach sorgen so noch genvgen gesiht

<<< Übersicht <<< vorige Seite nächste Seite >>>